# --------------------------------------------------------------------
# UnitTest fr die Lohnsteuerberechnung in LST2005
# $Id: test_Lohnsteuer.py,v 1.2 2005/01/27 10:16:14 wilde Exp $
# --------------------------------------------------------------------
#
# Copyright (c) 2005 by Intevation GmbH
# Authors:
# Sascha Wilde <wilde@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with this package for details.

"""Unit Test fr die Lohnsteuerberechnung in LST2005.  Benutzt die
Daten aus der Prftabelle zum offiziellen Programmablaufplan zur
maschinellen Jahreslohnsterberechnung 2005."""

# ACHTUNG: die Prftabelle liefert nur Referenzwerte fr die
# Berechnung der Lohnsteuer auf ein Jahr, andere Berechnungeitrume
# werden nicht bercksichtigt.

import unittest
from LST2005 import *

class TestGetLohnsteuer(unittest.TestCase):

    def SetUp(self):
        """Offizielle Prftabelle und LStRechner2005 einrichten"""        
        self.prueftabelle = {
            5000 : [     0.0,     0.0,     0.0,     0.0,   612.0,   750.0 ],
            7500 : [     0.0,     0.0,     0.0,     0.0,   987.0,  1125.0 ],
            10000: [     0.0,     0.0,     0.0,     0.0,  1362.0,  1739.0 ],
            12500: [   232.0,    18.0,     0.0,   232.0,  2403.0,  2789.0 ],
            15000: [   714.0,   444.0,     0.0,   714.0,  3400.0,  3722.0 ],
            17500: [  1362.0,  1043.0,     0.0,  1362.0,  4266.0,  4576.0 ],
            20000: [  2063.0,  1727.0,     0.0,  2063.0,  5126.0,  5458.0 ],
            22500: [  2725.0,  2375.0,   264.0,  2725.0,  6044.0,  6398.0 ],
            25000: [  3417.0,  3051.0,   628.0,  3417.0,  7020.0,  7394.0 ],
            27500: [  4126.0,  3746.0,  1104.0,  4126.0,  8052.0,  8438.0 ],
            30000: [  4860.0,  4465.0,  1634.0,  4860.0,  9102.0,  9488.0 ],
            32500: [  5620.0,  5211.0,  2240.0,  5620.0, 10152.0, 10538.0 ],
            35000: [  6408.0,  5984.0,  2952.0,  6408.0, 11202.0, 11588.0 ],
            37500: [  7224.0,  6785.0,  3684.0,  7224.0, 12252.0, 12638.0 ],
            40000: [  8068.0,  7614.0,  4364.0,  8068.0, 13302.0, 13688.0 ],
            42500: [  8938.0,  8470.0,  5026.0,  8938.0, 14352.0, 14738.0 ],
            45000: [  9836.0,  9354.0,  5700.0,  9836.0, 15402.0, 15788.0 ],
            47500: [ 10762.0, 10265.0,  6390.0, 10762.0, 16452.0, 16838.0 ],
            50000: [ 11715.0, 11203.0,  7094.0, 11715.0, 17502.0, 17888.0 ],
            52500: [ 12696.0, 12169.0,  7806.0, 12696.0, 18552.0, 18938.0 ],
            55000: [ 13704.0, 13163.0,  8524.0, 13704.0, 19602.0, 19988.0 ],
            57500: [ 14733.0, 14183.0,  9254.0, 14733.0, 20652.0, 21038.0 ],
            60000: [ 15763.0, 15213.0, 10000.0, 15763.0, 21702.0, 22088.0 ]
            }
        self.t = LStRechner2005()
        self.t.SetZeitraum(JAHR)

    def test_lohnsteuer(self):
        """Testet GetLohnsteuer gegen die offizielle Prftabelle"""        
        self.SetUp()
        for lohn in self.prueftabelle.keys():
            for stkl in range(1, 7):
                self.t.SetLohn(lohn)
                self.t.SetSteuerklasse(stkl)
                self.t.Calc()
                self.assertEquals(self.t.GetLohnsteuer(),
                                  self.prueftabelle[lohn][stkl - 1])

    def test_api_lohnaequi(self):
        """Testet SetLohn GetLohn quivalenz"""
        self.SetUp()
        for val in (0, 1, 1234.56, 2000.01, 2000.10, 2000.30, 2000.50, 3000,
                    3000.01, 50000, 70000, 90000, 1000000.01, 100000000000.01):
            self.t.SetLohn(val)
            self.assertEquals(self.t.GetLohn(), val)

    def test_api_zeitraumaequi(self):
        """Testet SetZeitraum GetZeitraum quivalenz"""
        self.SetUp()
        for val in (JAHR, MONAT, WOCHE, TAG):
            self.t.SetZeitraum(val)
            self.assertEquals(self.t.GetZeitraum(), val)

    def test_api_steuerklasseaequi(self):
        """Testet SetSteuerklasse GetSteuerklasse quivalenz"""
        self.SetUp()
        for val in (I, II, III, IV, V, VI):
            self.t.SetSteuerklasse(val)
            self.assertEquals(self.t.GetSteuerklasse(), val)

    def test_api_kirchensteueraequi(self):
        """Testet SetKirchensteuer GetKirchensteuer quivalenz"""
        self.SetUp()
        for val in (0, 1, 5.5, 14.32, 8, 9, 50.50, 87.65, 100):
            self.t.SetKirchensteuerProzent(val)
            self.assertEquals(self.t.GetKirchensteuerProzent(), val)


if __name__ == "__main__":
    unittest.main()
